Great to see you here 🫶 We are extremely open to contributions!

Do you have a connector you want to see included in Lemon AI or do you want to contribute in any other way? That's amazing 🥳 Just reach out or directly create a [Pull Request](https://docs.github.com/en/get-started/quickstart/contributing-to-projects).

Please make sure to use the [Pull Request Template](https://github.com/felixbrock/lemonai-py-client/blob/main/.github/PULL_REQUEST_TEMPLATE.md).
